@@ -41,7 +41,6 @@ HWGame::HWGame(GameUIConfig * config, GameCFGWidget * gamecfg, QString ammo, Tea
 {
     this->config = config;
     this->gamecfg = gamecfg;
-    TeamCount = 0;
     netSuspend = false;
 }
 
@@ -99,7 +98,7 @@ void HWGame::commonConfig()
             HWProto::addStringToBuffer(buf, QString("eammreinf %1").arg(ammostr.mid(3 * cAmmoNumber, cAmmoNumber)));
             if(!gamecfg->schemeData(21).toBool()) HWProto::addStringToBuffer(buf, QString("eammstore"));
             HWProto::addStringListToBuffer(buf,
-                team.TeamGameConfig(gamecfg->getInitHealth()));
+                team.teamGameConfig(gamecfg->getInitHealth()));
             ;
         }
     }
@@ -120,27 +119,23 @@ void HWGame::SendQuickConfig()
             .arg((themesModel->rowCount() > 0) ? themesModel->index(rand() % themesModel->rowCount()).data().toString() : "steel"));
     HWProto::addStringToBuffer(teamscfg, "eseed " + QUuid::createUuid().toString());
 
-    HWNamegen namegen;
-
-    HWTeam * team1;
-    team1 = new HWTeam;
-    team1->difficulty = 0;
-    team1->teamColor = QColor(colors[0]);
-    team1->numHedgehogs = 4;
-    namegen.TeamRandomNames(team1,TRUE);
+    HWTeam team1;
+    team1.setDifficulty(0);
+    team1.setColor(QColor(colors[0]));
+    team1.setNumHedgehogs(4);
+    HWNamegen::teamRandomNames(team1,true);
     HWProto::addStringListToBuffer(teamscfg,
-            team1->TeamGameConfig(100));
+            team1.teamGameConfig(100));
 
-    HWTeam * team2;
-    team2 = new HWTeam;
-    team2->difficulty = 4;
-    team2->teamColor = QColor(colors[1]);
-    team2->numHedgehogs = 4;
-	do
-        namegen.TeamRandomNames(team2,TRUE);
-	while(!team2->TeamName.compare(team1->TeamName) || !team2->Hedgehogs[0].Hat.compare(team1->Hedgehogs[0].Hat));
+    HWTeam team2;
+    team2.setDifficulty(4);
+    team2.setColor(QColor(colors[1]));
+    team2.setNumHedgehogs(4);
+    do
+        HWNamegen::teamRandomNames(team2,true);
+    while(!team2.name().compare(team1.name()) || !team2.hedgehog(0).Hat.compare(team1.hedgehog(0).Hat));
     HWProto::addStringListToBuffer(teamscfg,
-            team2->TeamGameConfig(100));
+            team2.teamGameConfig(100));
 
     HWProto::addStringToBuffer(teamscfg, QString("eammloadt %1").arg(cDefaultAmmoStore->mid(0, cAmmoNumber)));
     HWProto::addStringToBuffer(teamscfg, QString("eammprob %1").arg(cDefaultAmmoStore->mid(cAmmoNumber, cAmmoNumber)));
@@ -320,13 +315,6 @@ QStringList HWGame::getArguments()
     return arguments;
 }
 
-void HWGame::AddTeam(const QString & teamname)
-{
-    if (TeamCount == 5) return;
-    teams[TeamCount] = teamname;
-    TeamCount++;
-}
-
 void HWGame::PlayDemo(const QString & demofilename, bool isSave)
 {
     gameType = isSave ? gtSave : gtDemo;
@@ -394,13 +382,9 @@ void HWGame::SetGameState(GameState state)
     emit GameStateChanged(state);
 }
 
-void HWGame::KillAllTeams()
+void HWGame::abort()
 {
-    if (m_pTeamSelWidget)
-    {
-        QByteArray buf;
-        foreach(HWTeam team, m_pTeamSelWidget->getPlayingTeams())
-            HWProto::addStringToBuffer(buf, QString("eteamgone %1").arg(team.TeamName));
-        RawSendIPC(buf);
-    }
+    QByteArray buf;
+    HWProto::addStringToBuffer(buf, QString("efinish"));
+    RawSendIPC(buf);
 }
