@@ -64,24 +64,76 @@
         <source>When this option is enabled selecting a game scheme will auto-select a weapon</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Game Options</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HWChatWidget</name>
     <message>
         <source>%1 *** %2 has been removed from your ignore list</source>
-        <translation>%1 *** %2 تم حذفة من قائمة الترك</translation>
+        <translation type="obsolete">%1 *** %2 تم حذفة من قائمة الترك</translation>
     </message>
     <message>
         <source>%1 *** %2 has been added to your ignore list</source>
-        <translation>%1 *** %2 تم اضافته الى قائمة النرك</translation>
+        <translation type="obsolete">%1 *** %2 تم اضافته الى قائمة النرك</translation>
     </message>
     <message>
         <source>%1 *** %2 has been removed from your friends list</source>
-        <translation>%1 *** %2 تم حذقه الى قائمة الاصدقاء</translation>
+        <translation type="obsolete">%1 *** %2 تم حذقه الى قائمة الاصدقاء</translation>
     </message>
     <message>
         <source>%1 *** %2 has been added to your friends list</source>
-        <translation>%1 *** %2 تم حذفة من قائمة الاصدقاء</translation>
+        <translation type="obsolete">%1 *** %2 تم حذفة من قائمة الاصدقاء</translation>
+    </message>
+    <message>
+        <source>%1 has been removed from your ignore list</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 has been added to your ignore list</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 has been removed from your friends list</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 has been added to your friends list</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Stylesheet imported from %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter %1 if you want to use the current StyleSheet in future, enter %2 to reset!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Couldn&apos;t read %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>StyleSheet discarded</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>StyleSheet saved to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to save StyleSheet to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 is not a valid command!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Kicking %1 ...</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -132,6 +184,40 @@
         <source>Demo name:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Game aborted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation type="unfinished">كلمة السر</translation>
+    </message>
+    <message>
+        <source>Your nickname %1 is
+registered on Hedgewars.org
+Please provide your password below
+or pick another nickname in game config:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No password supplied.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Nickname</source>
+        <translation type="unfinished">اسم اللاعب</translation>
+    </message>
+    <message>
+        <source>Some one already uses
+ your nickname %1
+on the server.
+Please pick another nickname:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No nickname supplied.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HWGame</name>
@@ -258,7 +344,7 @@
     </message>
     <message>
         <source>Password</source>
-        <translation>كلمة السر</translation>
+        <translation type="obsolete">كلمة السر</translation>
     </message>
     <message>
         <source>Your nickname %1 is
@@ -286,22 +372,12 @@ or pick another nickname:</source>
         <source>%1 *** %2 has left</source>
         <translation>%1 *** %2 خرج</translation>
     </message>
-    <message>
-        <source>Your nickname %1 is
-registered on Hedgewars.org
-Please provide your password below
-or pick another nickname in game config:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Nickname</source>
-        <translation type="unfinished">اسم اللاعب</translation>
+        <translation type="obsolete">اسم اللاعب</translation>
     </message>
     <message>
-        <source>Some one already uses
- your nickname %1
-on the server.
-Please pick another nickname:</source>
+        <source>User quit</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -359,7 +435,7 @@ Please pick another nickname:</source>
     </message>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished">الغاء</translation>
+        <translation type="obsolete">الغاء</translation>
     </message>
 </context>
 <context>
@@ -483,6 +559,13 @@ Please pick another nickname:</source>
         </translation>
     </message>
 </context>
+<context>
+    <name>PageInGame</name>
+    <message>
+        <source>In game...</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>PageMain</name>
     <message>
@@ -968,10 +1051,6 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Random Maze</source>
         <translation type="unfinished">متاهة عشوائية</translation>
     </message>
-    <message>
-        <source>State:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Rules:</source>
         <translation type="unfinished"></translation>
@@ -1167,7 +1246,7 @@ Do you still want to join the room?</source>
     </message>
     <message>
         <source>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</source>
-        <translation>نمط التدريب، تحت التطوير</translation>
+        <translation type="obsolete">نمط التدريب، تحت التطوير</translation>
     </message>
     <message>
         <source>Demos (Watch recorded demos)</source>
@@ -1178,7 +1257,22 @@ Do you still want to join the room?</source>
         <translation>تحميل</translation>
     </message>
     <message>
-        <source>Campaign Mode (...). IN DEVELOPMENT</source>
+        <source>Campaign Mode (...)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Training Mode (Practice your skills in a range of training missions)</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>PageTraining</name>
+    <message>
+        <source>No description available</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select a mission!</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1474,7 +1568,7 @@ Do you still want to join the room?</source>
     </message>
     <message>
         <source>This program is distributed under the GNU General Public License</source>
-        <translation>This program is distributed under the GNU General Public License</translation>
+        <translation type="obsolete">This program is distributed under the GNU General Public License</translation>
     </message>
     <message>
         <source>Developers:</source>
@@ -1632,10 +1726,6 @@ Do you still want to join the room?</source>
         <source>Stereo rendering</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Game Options</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Style</source>
         <translation type="unfinished"></translation>
@@ -1652,6 +1742,10 @@ Do you still want to join the room?</source>
         <source>% Get Away Time</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>This program is distributed under the GNU General Public License v2</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QLineEdit</name>
