@@ -62,23 +62,59 @@
         <source>When this option is enabled selecting a game scheme will auto-select a weapon</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Game Options</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HWChatWidget</name>
     <message>
-        <source>%1 *** %2 has been removed from your ignore list</source>
+        <source>%1 has been removed from your ignore list</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>%1 *** %2 has been added to your ignore list</source>
+        <source>%1 has been added to your ignore list</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>%1 *** %2 has been removed from your friends list</source>
+        <source>%1 has been removed from your friends list</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>%1 *** %2 has been added to your friends list</source>
+        <source>%1 has been added to your friends list</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Stylesheet imported from %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter %1 if you want to use the current StyleSheet in future, enter %2 to reset!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Couldn&apos;t read %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>StyleSheet discarded</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>StyleSheet saved to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to save StyleSheet to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 is not a valid command!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Kicking %1 ...</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -126,6 +162,40 @@
         <source>Demo name:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Game aborted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your nickname %1 is
+registered on Hedgewars.org
+Please provide your password below
+or pick another nickname in game config:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No password supplied.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Nickname</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Some one already uses
+ your nickname %1
+on the server.
+Please pick another nickname:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No nickname supplied.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HWGame</name>
@@ -250,10 +320,6 @@
         <source>You got kicked</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Password</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>%1 *** %2 has joined the room</source>
         <translation type="unfinished"></translation>
@@ -271,21 +337,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Your nickname %1 is
-registered on Hedgewars.org
-Please provide your password below
-or pick another nickname in game config:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Nickname</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Some one already uses
- your nickname %1
-on the server.
-Please pick another nickname:</source>
+        <source>User quit</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -333,10 +385,6 @@ Please pick another nickname:</source>
         <source>Connecting...</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Cancel</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>PageDrawMap</name>
@@ -439,6 +487,13 @@ Please pick another nickname:</source>
         </translation>
     </message>
 </context>
+<context>
+    <name>PageInGame</name>
+    <message>
+        <source>In game...</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>PageMain</name>
     <message>
@@ -905,10 +960,6 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Random Maze</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>State:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Rules:</source>
         <translation type="unfinished"></translation>
@@ -1093,10 +1144,6 @@ Do you still want to join the room?</source>
         <source>Multiplayer (play a hotseat game against your friends, or AI teams)</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Demos (Watch recorded demos)</source>
         <translation type="unfinished"></translation>
@@ -1106,7 +1153,22 @@ Do you still want to join the room?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Campaign Mode (...). IN DEVELOPMENT</source>
+        <source>Campaign Mode (...)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Training Mode (Practice your skills in a range of training missions)</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>PageTraining</name>
+    <message>
+        <source>No description available</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select a mission!</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1388,10 +1450,6 @@ Do you still want to join the room?</source>
         <source>Version</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>This program is distributed under the GNU General Public License</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Developers:</source>
         <translation type="unfinished"></translation>
@@ -1548,10 +1606,6 @@ Do you still want to join the room?</source>
         <source>Stereo rendering</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Game Options</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Style</source>
         <translation type="unfinished"></translation>
@@ -1568,6 +1622,10 @@ Do you still want to join the room?</source>
         <source>% Get Away Time</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>This program is distributed under the GNU General Public License v2</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QLineEdit</name>
