@@ -17,7 +17,7 @@ locale = {
     ["Barrel Eater!"] = "Pożeracz Beczek!",
     ["Barrel Launcher"] = "Wyrzutnia Beczek",
     ["Bat balls at your enemies and|push them into the sea!"] = "Uderzaj piłkami w swoich przeciwników|i strącaj ich do wody!",
-    ["Bat your opponents through the|baskets and out of the map!"] = "Uderzaj swoich przekiwników|wyrzucając przez kosz, poza mapę!",
+    ["Bat your opponents through the|baskets and out of the map!"] = "Uderzaj swoich przeciwników|wyrzucając przez kosz, poza mapę!",
     ["Bazooka Training"] = "Trening bazooki",
     ["Best laps per team: "] = "Najszybsze okrążenie drużyny: ",
     ["Best Team Times: "] = "Najlepszy czas zespołów",
@@ -26,7 +26,7 @@ locale = {
     ["BOOM!"] = "BUM!",
     ["Boss defeated!"] = "Boss pokonany!",
     ["Boss Slayer!"] = "Pogromca bossów",
-    ["Build a track and race."] = "Zbuduj trasię i ścigaj się.",
+    ["Build a track and race."] = "Zbuduj trasę i ścigaj się.",
     ["CAPTURE THE FLAG"] = "PRZECHWYĆ FLAGĘ",
     ["Careless"] = "Nieostrożny",
     ["Change Weapon"] = "Zmień broń",
@@ -66,7 +66,7 @@ locale = {
     ["Flag captured!"] = "Flaga przechwycona!",
     ["Flag respawned!"] = "Flaga przywrócona!",
     ["Flag returned!"] = "Flaga odzyskana!",
-    ["Flags, and their home base will be placed where each team ends their first turn."] = "Flagi i baza zostaną umieszzcone tam gdzie zespół zakończy swą pierwszą turę.",
+    ["Flags, and their home base will be placed where each team ends their first turn."] = "Flagi i baza zostaną umieszczone tam gdzie zespół zakończy swą pierwszą turę.",
 --      ["Flamer"] = "",
 --      ["Friendly Fire!"] = "",
     ["fuel extended!"] = "zdobyto paliwo",
@@ -97,7 +97,7 @@ locale = {
     ["Hooray!"] = "Hurraaa!",
     ["Hunter"] = "Strzelec",  
     ["Instructor"] = "Instruktor",  
-    ["invaders destroyed"] = "najeźdzców zniszczonych",
+    ["invaders destroyed"] = "najeźdźców zniszczonych",
     ["It's a good thing SUDDEN DEATH is 99 turns away..."] = "Jak to dobrze, że Nagła Śmierć jest dopiero za 99 tur...",
     ["Jumping is disabled"] = "Skakanie jest niemożliwe",
 --      ["Kamikaze Expert!"] = "",
@@ -129,10 +129,10 @@ locale = {
     ["Oh no! Time's up! Just try again."] = "Ajajaj! Koniec czasu! Spróbuj jeszcze raz.",  
     ["Operation Diver"] = "Operacja Nurek",
     ["Opposing Team: "] = "Przeciwna drużyna",
-    ["Pathetic Hog #%d"] = "Załosny Jeż #%d",
+    ["Pathetic Hog #%d"] = "Żałosny Jeż #%d",
 --      ["Pathetic Resistance"] = "", -- User_Mission_-_Bamboo_Thicket, User_Mission_-_Newton_and_the_Hammock
     ["Per-Hog Ammo"] = "Oddzielna amunicja dla jeży",
-    ["Place more waypoints using [ENTER]"] = "Postaw więcej punktów orientacyjnych za pomocą [Entera]",
+    ["Place more waypoints using [ENTER]"] = "Postaw więcej punktów orientacyjnych za pomocą [Enteru]",
     ["Place more waypoints using the 'Air Attack' weapon."] = "Postaw więcej punktów orientacyjnych używając [Nalotu]",
     ["points"] = "punkty", -- Control, CTF_Blizzard, Basic_Training_-_Bazooka, Basic_Training_-_Shotgun, Basic_Training_-_Sniper_Rifle
     ["Poison"] = "Truciciel",
@@ -203,7 +203,7 @@ locale = {
 --      ["Unlimited Attacks"] = "",
     ["Unstoppable!"] = "Nie do zatrzymania!",
 --      ["User Challenge"] = "",
-    ["Use your rope to get from start to finish as fast as you can!"] = "Użyj liny by jak najszybciej dotrzec od startu do mety",
+    ["Use your rope to get from start to finish as fast as you can!"] = "Użyj liny by jak najszybciej dotrzeć od startu do mety",
     ["Victory for the "] = "Zwycięstwo przypadło",
     ["Waypoint placed."] = "Postawiono punkt kontrolny",
     ["Way-Points Remaining"] = "Pozostało punktów: ",
