@@ -5,54 +5,54 @@ locale = {
         ["Accuracy Bonus!"] = "Bonus za presnosť!",
         ["a Hedgewars mini-game"] = "minihra Hedgewars", -- Space_Invasion, The_Specialists
 	["Aiming Practice"] = "Tréning presnosti", --Bazooka, Shotgun, SniperRifle
-        ["Ammo"] = "Munícia",
-        ["Ammo Depleted!"] = "Munícia vyčerpaná!",
-        ["Ammo Maniac!"] = "Muničný maniak!",
+        ["Ammo"] = "Výzbroj",
+        ["Ammo Depleted!"] = "Výzbroj vyčerpaná!",
+--      ["Ammo Maniac!"] = "",
         ["Available points remaining: "] = "Zostávajúci počet bodov: ",
 	["Bat balls at your enemies and|push them into the sea!"] = "Loptami triafajte vašich nepriateľov|a zhoďte ich tak do mora!",
-	["Bat your opponents through the|baskets and out of the map!"] = "Odpálkujte vašich súperov cez kôš|von z mapy!",
+	["Bat your opponents through the|baskets and out of the map!"] = "Odpálkujte vašich súperov do koša|a von z mapy!",
 	["Bazooka Training"] = "Tréning s bazukou",
 	["Best laps per team: "] = "Najrýchlejšie kolá podľa tímov: ",
-        ["Best Team Times: "] = "Najlepšie tímové časy: ",
+        ["Best Team Times: "] = "Najrýchlejšie tímové časy: ",
         ["Bloody Rookies"] = "Mizerní zelenáči", -- 01#Boot_Camp, User_Mission_-_Dangerous_Ducklings, User_Mission_-_Diver, User_Mission_-_Spooky_Tree
         ["BOOM!"] = "BUM!",
         ["Boom!"] = "Bum!",
         ["Boss defeated!"] = "Vodca bol porazený!",
-        ["Boss Slayer!"] = "Vodca zabitý!",
+--      ["Boss Slayer!"] = "",
         ["CAPTURE THE FLAG"] = "ZMOCNITE SA VLAJKY",
-        ["Careless"] = "Neopatrný",
+        ["Careless"] = "Bezstarostný",
         ["Clumsy"] = "Nešikovný",
-        ["Codename: Teamwork"] = "Krycie meno: Tímová práca",
-        ["Complete the track as fast as you can!"] = "Dokončite trasu tak rýchlo, ako len viete! ",
+        ["Codename: Teamwork"] = "Kódové meno: Tímová práca",
+--      ["Complete the track as fast as you can!"] = "",
         ["Congratulations!"] = "Gratulujem!",
 	["Congratulations! You've eliminated all targets|within the allowed time frame."] = "Gratulujem! Zneškodnili ste všetky ciele|v stanovenom čase.", --Bazooka, Shotgun, SniperRifle
-        ["Control pillars to score points."] = "Obsaďte piliere, aby ste skórovali",
+        ["Control pillars to score points."] = "Ovládnite piliere, aby ste skórovali",
         ["Cybernetic Empire"] = "Kybertnetické impérium",
         ["DAMMIT, ROOKIE! GET OFF MY HEAD!"] = "Do kelu s tebou, zelenáč! Okamžite mi zlez z hlavy!",
         ["DAMMIT, ROOKIE!"] = "Prekliaty zelenáč!",
         ["Dangerous Ducklings"] = "Nebezpečné kačiatka",
-        ["Deadweight"] = "Mŕtva váha",
-        ["Depleted Kamikaze!"] = "Vyčerpaný samovrah!",
-        ["Destroy invaders to score points."] = "Zničte votrelcov a získajte tak body.",
-        ["Drone Hunter!"] = "Lovec včeliakov!",
-        ["Drowner"] = "Utopenec",
-        ["Each turn you get 1-3 random weapons"] = "Každé kolo získate 1-3 náhodných zbraní",
-        ["Each turn you get one random weapon"] = "Každé kolo získate jednu náhodnú zbraň",
+--      ["Deadweight"] = "",
+--      ["Depleted Kamikaze!"] = "",
+--      ["Destroy invaders to score points."] = "",
+--      ["Drone Hunter!"] = "",
+--      ["Drowner"] = "",
+--      ["Each turn you get 1-3 random weapons"] = "",
+        ["Each turn you get one random weapon"] = "Každé koho dostanete jednu náhodnú zbraň",
         ["Eliminate all enemies"] = "Zneškodnite všetkých nepriateľov",
 	["Eliminate all targets before your time runs out.|You have unlimited ammo for this mission."] = "Zneškodnite všetky ciele pred vypršaním času.|Na túto misiu máte neobmedzené množstvo streliva.", --Bazooka, Shotgun, SniperRifle
         ["Eliminate Poison before the time runs out"] = "Zneškodnite Poisona pred tým, ako vyprší čas",
         ["Eliminate the Blue Team"] = "Zneškodnite modrý tím",
-        ["Eliminate the enemy specialists."] = "Zneškodnite nepriateľských špecialistov.",
+--      ["Eliminate the enemy specialists."] = "",
         ["- Eliminate Unit 3378 |- Feeble Resistance must survive"] = "- Zneškodnite Jednotku 3378|- Slabý odpor musí prežiť",
         ["Enjoy the swim..."] = "Užite si plávanie...",
-        ["[Enter]"] = "[Enter]",
+--      ["[Enter]"] = "",
 	["Fastest lap: "] = "Najrýchlejšie kolo: ",
         ["Feeble Resistance"] = "Slabý odpor",
-        ["Fire"] = "Oheň",
+--      ["Fire"] = "",
         ["Flag captured!"] = "Získaná vlajka!",
         ["Flag respawned!"] = "Vlajka obnovená!",
         ["Flag returned!"] = "Vlajka vrátená!",
-        ["Flags, and their home base will be placed where each team ends their first turn."] = "Vlajky a domovské základne budú umiestnené tam, kde každý tím skončí svoj prvý ťah.",
+--      ["Flags, and their home base will be placed where each team ends their first turn."] = "",
         ["GAME BEGUN!!!"] = "HRA ZAČALA!!!",
         ["Game Modifiers: "] = "Modifikátory hry: ",
         ["GAME OVER!"] = "KONIEC HRY!",
@@ -64,41 +64,41 @@ locale = {
         ["Good luck out there!"] = "Veľa šťastia!",
         ["GOTCHA!"] = "A MÁM ŤA!",
         ["Hahahaha!"] = "Hehehehe!",
-        ["Haha, now THAT would be something!"] = "Haha, tak TOTO bude niečo!",
-        ["Hapless Hogs"] = "Nešťastný ježko",
-        [" Hapless Hogs left!"] = " Nešťastný ježko odišiel!",
+        ["Haha, now THAT would be something!"] = "Haha, tak TO by bolo niečo!",
+--      ["Hapless Hogs"] = "",
+--      [" Hapless Hogs left!"] = "",
         ["Heavy"] = "Ťažký",
 	["Hedgewars-Basketball"] = "Hedgewars-Basketbal",
-	["Hedgewars-Knockball"] = "Hedgewars-Vybíjaná",
+	["Hedgewars-Knockball"] = "Hedgewars-Knockball",
         ["Heh, it's not that bad."] = "Heh, to nie je také zlé.",
-        ["Hit Combo!"] = "Opakovaný zásah!",
+--      ["Hit Combo!"] = "",
         ["Hmmm..."] = "Hmm..",
         ["Hooray!"] = "Hurá!",
 	["Hunter"] = "Lovec", --Bazooka, Shotgun, SniperRifle
         ["Instructor"] = "Inštruktor", -- 01#Boot_Camp, User_Mission_-_Dangerous_Ducklings
-        ["invaders destroyed"] = "votrelci zničení",
-        ["It's a good thing SUDDEN DEATH is 99 turns away..."] = "Je dobré, že NÁHLA SMRŤ je tu až za 99 ťahov...",
-        ["Jumping is disabled"] = "Skákanie je vypnuté",
-        ["Kamikaze Expert!"] = "Expert na samovraždy!",
+--      ["invaders destroyed"] = "",
+--      ["It's a good thing SUDDEN DEATH is 99 turns away..."] = "",
+--      ["Jumping is disabled"] = "",
+--      ["Kamikaze Expert!"] = "",
         ["KILLS"] = "ZABITÍ:",
         ["[Left Shift]"] = "[Ľavý Shift]",
         ["Listen up, maggot!!"] = "Počúvaj, ty biedny červ!",
         ["|- Mines Time:"] = "|- Časovač pre míny:", -- User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork
         ["MISSION FAILED"] = "MISIA NEÚSPEŠNÁ", -- User_Mission_-_Dangerous_Ducklings, User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork
-        ["MISSION SUCCESS"] = "MISIA ÚSPEŠNÁ",
+--      ["MISSION SUCCESS"] = "",
         ["MISSION SUCCESSFUL"] = "MISIA ÚSPEŠNÁ", -- User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork
         ["Movement: [Up], [Down], [Left], [Right]"] = "Pohyb: [Hore], [Dole], [Vľavo], [Vpravo]",
-        ["Multi-shot!"] = "Opakovaná rana!",
+--      ["Multi-shot!"] = "",
         ["Nameless Heroes"] = "Hrdinovia bez mena",
         ["NEW CLAN RECORD: "] = "NOVÝ KLANOVÝ REKORD: ",
 	["NEW fastest lap: "] = "NOVÉ najrýchlejšie kolo: ",
-        ["NEW RACE RECORD: "] = "NOVÝ TRAŤOVÝ REKORD: ",
-        ["NOT ENOUGH WAYPOINTS"] = "NEDOSTATOK NAVIGAČNÝCH BODOV",
+--      ["NEW RACE RECORD: "] = "",
+--      ["NOT ENOUGH WAYPOINTS"] = "",
 	["Not So Friendly Match"] = "Nie tak celkom priateľský zápas", -- Basketball, Knockball
         ["Oh no! Just try again!"] = "Áále nie! Tak to skúste znovu!", -- User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork
 	["Oh no! Time's up! Just try again."] = "Áále nie! Čas vypršal! Tak to skúste znovu.", --Bazooka, Shotgun, SniperRifle
         ["Operation Diver"] = "Operácia Potápač",
-        ["Opposing Team: "] = "Nepriateľský tím: ",
+        ["Opposing Team: "] = "Nepriateľský tím",
         ["Pathetic Hog #%d"] = "Žalostný ježko #%d",
         ["Per-Hog Ammo"] = "Samostatná munícia pre ježkov",
         ["Place more waypoints using [ENTER]"] = "Umiesnite viac bodov pomocou [ENTER]u",
@@ -106,13 +106,13 @@ locale = {
         ["Poison"] = "Poison",
         ["Power Remaining"] = "Zostáva energie",
         ["Press [Precise] to skip intro"] = "Stlačte [Presnejšie mierenie] pre preskočenie intra",
-        ["Race complexity limit reached."] = "Dosiahnutý limit zložitosti pretekov.",
-        [" - Return the enemy flag to your base to score | - First team to 3 captures wins | - You may only score when your flag is in your base | - Hogs will drop the flag if killed, or drowned | - Dropped flags may be returned or recaptured | - Hogs respawn when killed"] = " - Skórujete prinesením nepriateľskej vlajky do vašej základne | -  Prvý tím, ktorý dosiahne 3 body, vyhráva | - Skórujete len vtedy, keď je máte svoju vlajku v základni | - Spadnuté vlajky môžu byť vrátené na základňu alebo sa ich môže zmocniť súper | - Ježkovia po smrti ožijú",
-        ["Round Limit"] = "Limit kôl",
+--      ["Race complexity limit reached."] = "",
+        [" - Return the enemy flag to your base to score | - First team to 3 captures wins | - You may only score when your flag is in your base | - Hogs will drop the flag if killed, or drowned | - Dropped flags may be returned or recaptured | - Hogs respawn when killed"] = " - Skórujete prinesením nepriateľskej vlajky do vašej základne | -  Prvý tím, ktorý dosiahne 3 body, vyhráva | - Skórujete len vtedy, keď je máte svoju vlajku v základni | - Spadnuté vlajky môžu byť vrátené na základňu alebo sa ich môže zmocniť súpere | - Ježkovia po smrti ožiujú",
+        ["Round Limit"] = "Limit na kolo",
         ["Rounds Complete"] = "Dokončených kôl",
         ["RULES OF THE GAME [Press ESC to view]"] = "PRAVIDLÁ HRY [Stlačte Esc pre ich zobrazenie]",
-        ["s|"] = "s|",
-        ["Save as many hapless hogs as possible!"] = "Zachráňte toľko nešťastných ježkov, koľko len môžete!",
+--      ["s|"] = "",
+--      ["Save as many hapless hogs as possible!"] = "",
         ["SCORE"] = "SKÓRE",
         ["sec"] = "sek", -- CTF_Blizzard, TrophyRace, Basic_Training_-_Bazooka, Basic_Training_-_Shotgun, Basic_Training_-_Sniper_Rifle, User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork, Capture_the_Flag
         ["See ya!"] = "Tak zatiaľ!",
@@ -120,56 +120,56 @@ locale = {
         ["Shield boosted! +30 power"] = "Štít posilnený! Energia +30",
         ["Shield Depleted"] = "Štít vyčerpaný",
         ["Shield is fully recharged!"] = "Štít je plne nabitý!",
-        ["Shield Master!"] = "Štítový odborník",
-        ["Shield Miser!"] = "Štítový žgrloš",
+--      ["Shield Master!"] = "",
+--      ["Shield Miser!"] = "",
         ["Shield OFF:"] = "Štít VYPNUTÝ:",
         ["Shield ON:"] = "Štít ZAPNUTÝ:",
         ["Shield Seeker!"] = "Hľadač štítov!",
-	["Shotgun Team"] = "Tím s brokovnicou",
+	["Shotgun Team"] = "Shotgun tím",
 	["Shotgun Training"] = "Tréning s brokovnicou",
         ["Shots Left: "] = "Zostáva striel: ", -- GaudyRacer, Tumbler
-        ["Silly"] = "Hlúpy",
-        ["Sinky"] = "Prepadnutý",
+--      ["Silly"] = "",
+--      ["Sinky"] = "",
 	["%s is out and Team %d|scored a penalty!| |Score:"] = "%s je mimo hru a tím %d|dostal trestný bod!| |Skóre:", -- Basketball, Knockball
 	["%s is out and Team %d|scored a point!| |Score:"] = "%s je mimo hru a tím %d|získal bod!| |Skóre:", -- Basketball, Knockball
 	["Sniper Training"] = "Tréning pre ostreľovačov",
 	["Sniperz"] = "Ostreľovači",
-        ["Sponge"] = "Špongia",
+--      ["Sponge"] = "",
         ["Spooky Tree"] = "Strašidelný strom",
-        ["STATUS UPDATE"] = "AKTUALIZÁCIA STAVU", -- GaudyRacer, Space_Invasion
-        ["Switched to "] = "Prepnutý na ",
+--      ["STATUS UPDATE"] = "", -- GaudyRacer, Space_Invasion
+        ["Switched to "] = "Prepnuté na ",
 	["Team %d: "] = "Tím %d: ",
-        ["Team Scores"] = "Tímové skóre", -- Control, Space_Invasion
-        ["That Sinking Feeling"] = "Potopené pocity",
+--      ["Team Scores"] = "", -- Control, Space_Invasion
+--      ["That Sinking Feeling"] = "",
         ["That was pointless."] = "To bolo zbytočné.",
         ["The enemy is hiding out on yonder ducky!"] = "Nepriateľ sa schováva na tamtej kačičke!",
         ["The flag will respawn next round."] = "V ďalšom kole sa obnoví vlajka.",
-        ["The Nameless One"] = "Bez mena",
+--      ["The Nameless One"] = "",
         ["THE SPECIALISTS"] = "ŠPECIALISTI",
         ["This rain is really something..."] = "Ten dážď naozaj stojí za to...",
         ["TIME: "] = "ČAS: ",
-        ["Timed Kamikaze!"] = "Časovaná samovražda!",
+--      ["Timed Kamikaze!"] = "",
         ["Time Extended!"] = "Predĺžený čas!",
         ["Time Left: "] = "Zostávajúci čas: ",
         ["Toggle Shield"] = "Prepnúť štít",
-        ["Toxic Team"] = "Jedovatý tím", -- User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork
-        ["TRACK COMPLETED"] = "TRASA KOMPLETNÁ",
-        ["Track Time: "] = "Čas na trati: ",
+        ["Toxic Team"] = "Toxic tím", -- User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork
+--      ["TRACK COMPLETED"] = "",
+        ["Track Time: "] = "Čas: ",
 	["TrophyRace"] = "Preteky o trofej",
         ["T_T"] = "T_T",
         ["Turn Time"] = "Čas na ťah",
         ["Unit 3378"] = "Jednotka 3378",
         ["Unlimited Attacks"] = "Neobmedzené útoky",
-        ["User Challenge"] = "Výzva",
+--      ["User Challenge"] = "",
 	["Use your rope to get from start to finish as fast as you can!"] = "Použite lano na presun zo štartovnej pozície do cieľa tak rýchlo, ako to len viete!",
         ["v.06"] = "v.06",
         ["Victory for the "] = "Víťazstvo pre", -- CTF_Blizzard, Capture_the_Flag
-        ["Waypoint placed."] = "Navigačný bod umiestnený.",
-        ["Weapons Reset"] = "Zbrane obnovené",
-        ["WINNING TIME: "] = "VÍŤAZNÝ ČAS: ",
-        ["You'd almost swear the water was rising!"] = "Prisahali by ste, že voda stúpala!",
+--      ["Waypoint placed."] = "",
+--      ["Weapons Reset"] = "",
+        ["WINNING TIME: "] = "ČAS PRE VÍŤAZSTVO: ",
+--      ["You'd almost swear the water was rising!"] = "",
         ["You have SCORED!!"] = "SKÓROVALI ste!!",
-        ["You saved"] = "Uložili ste",
+        ["You saved"] = "Zachránili ste",
         ["You've failed. Try again."] = "Neuspeli ste. Skúste to znova.",
 	["You've reached the goal!| |Time: "] = "Dosiahli ste cieľ!| |Čas: ",
 	["'Zooka Team"] = "Bazuka tím",
