@@ -1,5 +1,5 @@
 --------------------------------
--- CTF_BLIZZARD 0.4
+-- CTF_BLIZZARD 0.9
 --------------------------------
 
 ---------
@@ -60,6 +60,36 @@
 -- changed the aura around the flag carrier / flag to an aura and added some support for this
 -- changed things so the seed is no longer always the same...
 
+---------
+-- 0.6
+---------
+
+-- removed branding and version number
+-- removed teleport from starting weapons
+-- increased captures to 3
+
+------------
+-- 0.7
+------------
+
+-- hopefully fixed a bug with the teleporters
+-- added a fix for crate possibly getting imbedded in land when it was near the water line
+
+------------
+-- 0.8
+------------
+
+-- fixed version control fail with missing check on onGearDelete
+
+-- changed hog placements code so that they start in the same place for both teams
+-- and hogs move in the same order, not backwards to each other.
+
+-----------
+-- 0.9
+------------
+
+-- add support for more players
+-- re-enable sudden death, but set water rise to 0
 
 loadfile(GetDataPath() .. "Scripts/Locale.lua")()
 
@@ -76,6 +106,8 @@ local roundsCounter = 0	-- used to determine when to spawn more crates
 						-- on ROUNDS instead?
 local effectTimer = 0
 
+local ropeGear = nil
+
 --------------------------
 -- hog and team tracking variales
 --------------------------
@@ -145,19 +177,21 @@ function ManageTeleporterEffects()
 	effectTimer = effectTimer + 1
 	if effectTimer > 50 then -- 100
 		effectTimer = 0
-		
-		for i = 0,1 do		
+
+		for i = 0,1 do
 			eX = 10 + zXMin[i] + GetRandom(zWidth[i]-10)
 			eY = 50 + zYMin[i] + GetRandom(zHeight[i]-110)
 
-	-- steam and smoke and DUST look good, smokering looks trippy 
+	-- steam and smoke and DUST look good, smokering looks trippy
 	-- smoketrace and eviltrace are not effected by wind?
 	-- chunk is a LR falling gear
-			tempE = AddVisualGear(eX, eY, vgtDust, 0, false)		
-			g1, g2, g3, g4, g5, g6, g7, g8, g9, g10 = GetVisualGearValues(tempE)
-			SetVisualGearValues(tempE, eX, eY, g3, g4, g5, g6, g7, g8, g9, fCol[i])
+			tempE = AddVisualGear(eX, eY, vgtDust, 0, false)
+			if tempE ~= 0 then
+				g1, g2, g3, g4, g5, g6, g7, g8, g9, g10 = GetVisualGearValues(tempE)
+				SetVisualGearValues(tempE, eX, eY, g3, g4, g5, g6, g7, g8, g9, fCol[i])
+			end
 		end
-	end 
+	end
 end
 
 function CreateZone(xMin, yMin, width, height)
@@ -201,7 +235,7 @@ function CheckScore(teamID)
 		winner = "Blue"
 	end
 
-	if fCaptures[teamID] == 2 then
+	if fCaptures[teamID] == 3 then
 		for i = 0, (numhhs-1) do
 			if GetHogClan(hhs[i]) == alt then
 				SetEffect(hhs[i], heResurrectable, false)
@@ -257,8 +291,8 @@ function FlagDeleted(gear)
 				fIsMissing[bbq] = false
 				fNeedsRespawn[bbq] = true
 				fCaptures[wtf] = fCaptures[wtf] +1					--fCaptures[wtf]
-				
-				--ShowMission(loc("You have SCORED!!"), "Red Team: " .. fCaptures[0], "Blue Team: " .. fCaptures[1], -amBazooka, 0)
+
+				--ShowMission(LOC_NOT("You have SCORED!!"), "Red Team: " .. fCaptures[0], "Blue Team: " .. fCaptures[1], -amBazooka, 0)
 				ShowMission(loc("You have SCORED!!"), GetHogTeamName(CurrentHedgehog) .. ": " .. fCaptures[wtf], loc("Opposing Team: ") .. fCaptures[bbq], 0, 0)
 
 				PlaySound(sndVictory)
@@ -340,8 +374,13 @@ function FlagThiefDead(gear)
 	end
 
 	if fThief[wtf] ~= nil then
-		--SetEffect(fThief[wtf], hePoisoned, false)
-		fGear[wtf] = SpawnAmmoCrate(fThiefX[wtf],fThiefY[wtf]-50,amSkip)
+		
+		if fThiefY[wtf] > 2040 then
+			fGear[wtf] = SpawnAmmoCrate(fThiefX[wtf],(fThiefY[wtf]+10),amSkip)
+		else
+			fGear[wtf] = SpawnAmmoCrate(fThiefX[wtf],(fThiefY[wtf]-50),amSkip)
+		end
+
 		AddVisualGear(fThiefX[wtf], fThiefY[wtf], vgtBigExplosion, 0, false)
 		fThief[wtf] = nil
 	end
@@ -349,7 +388,7 @@ function FlagThiefDead(gear)
 end
 
 function HandleCircles()
-	
+
 	for i = 0, 1 do
 		if fIsMissing[i] == false then -- draw a circle at the flag's spawning place
 			--SetVisualGearValues(fCirc[i], fSpawnX[i],fSpawnY[i], 20, 200, 0, 0, 100, 33, 2, fCol[i])
@@ -363,7 +402,7 @@ function HandleCircles()
 				SetVisualGearValues(fCirc[i], GetX(fGear[i]),GetY(fGear[i]), vCircMinA[i], vCircMaxA[i], vCircType[i], vCircPulse[i], vCircFuckAll[i], vCircRadius[i], vCircWidth[i], vCircCol[i])
 			end
 		end
-		
+
 		if fNeedsRespawn[i] == true then -- if the flag has been destroyed, no need for a circle
 			SetVisualGearValues(fCirc[i], fSpawnX[i],fSpawnY[i], 20, 200, 0, 0, 100, 0, 0, fCol[i])
 		end
@@ -408,7 +447,11 @@ function CheckTeleporters()
 
 	if teleportActive == true then
 		if actionReset == 0 then
-			SetGearMessage(CurrentHedgehog, gmAttack)
+			if ropeGear ~= nil then
+				if GetGearElasticity(ropeGear) ~= 0 then
+					SetGearMessage(CurrentHedgehog, gmAttack)
+				end
+			end
 			--AddCaption(actionReset .. ";" .. "attack")
 		elseif actionReset == 10 then
 			SetGearMessage(CurrentHedgehog, 0)
@@ -433,7 +476,7 @@ function RebuildTeamInfo()
 
 
 	-- make a list of individual team names
-	for i = 0, 5 do
+	for i = 0, (TeamsCount-1) do
 		teamNameArr[i] = i
 		teamSize[i] = 0
 		teamIndex[i] = 0
@@ -530,7 +573,8 @@ function onGameInit()
 	MinesTime  = 2000
 	Explosives = 0 -- The number of explosives being placed
 	Delay = 10 -- The delay between each round
-	SuddenDeathTurns = 99 -- suddendeath is off, effectively
+	WaterRise = 0 -- I sure hope this works	
+	--SuddenDeathTurns = 99 -- suddendeath is off, effectively
 	Map = "Blizzard" -- The map to be played
 	Theme = "Snow" -- The theme to be used "Nature"
 
@@ -539,8 +583,7 @@ end
 
 function onGameStart()
 
-	--ShowMission(loc(caption), loc(subcaption), loc(goal), 0, 0)
-	ShowMission(loc("CTF_BLIZZARD") .. " 0.5", loc("by mikade"), loc(" - Return the enemy flag to your base to score | - First team to 3 captures wins | - You may only score when your flag is in your base | - Hogs will drop the flag if killed, or drowned | - Dropped flags may be returned or recaptured | - Hogs respawn when killed"), 0, 0)
+	ShowMission("CTF_BLIZZARD", "", loc(" - Return the enemy flag to your base to score | - First team to 3 captures wins | - You may only score when your flag is in your base | - Hogs will drop the flag if killed, or drowned | - Dropped flags may be returned or recaptured | - Hogs respawn when killed"), 0, 0)
 
 
 	-- initialize teleporters
@@ -562,7 +605,7 @@ function onGameStart()
 					team1Placed = 0
 				end
 			elseif GetHogClan(hhs[g]) == 1 then
-				SetGearPosition(hhs[g],2230+ ((team2Placed+1)*50),1570)
+				SetGearPosition(hhs[g],2691- ((team2Placed+1)*50),1570)
 				team2Placed = team2Placed +1
 				if team2Placed > 6 then
 					team2Placed = 0
@@ -586,12 +629,12 @@ function onGameStart()
 	for i = 0, 1 do
 		fGear[i] = SpawnAmmoCrate(fSpawnX[i],fSpawnY[i],amSkip)
 		fCirc[i] = AddVisualGear(fSpawnX[i],fSpawnY[i],vgtCircle,0,true)
-		fCol[i] = GetClanColor(i)	
+		fCol[i] = GetClanColor(i)
 
 		fSpawnC[i] = AddVisualGear(fSpawnX[i],fSpawnY[i],vgtCircle,0,true)
-		SetVisualGearValues(fSpawnC[i], fSpawnX[i],fSpawnY[i], 10, 200, 1, 10, 0, 300, 5, fCol[i])		
-		
-	
+		SetVisualGearValues(fSpawnC[i], fSpawnX[i],fSpawnY[i], 10, 200, 1, 10, 0, 300, 5, fCol[i])
+
+
 		fIsMissing[i] = false
 		fNeedsRespawn[i] = false
 		fCaptures[i] = 0
@@ -631,7 +674,7 @@ function onNewTurn()
 	HandleCrateDrops()
 
 	--myC = AddVisualGear(GetX(CurrentHedgehog),GetY(CurrentHedgehog),vgtCircle,0,true)
-	--SetVisualGearValues(myC, GetX(CurrentHedgehog),GetY(CurrentHedgehog), 20, 200, 0, 0, 100, 50, 3, GetClanColor(GetHogClan(CurrentHedgehog)))	
+	--SetVisualGearValues(myC, GetX(CurrentHedgehog),GetY(CurrentHedgehog), 20, 200, 0, 0, 100, 50, 3, GetClanColor(GetHogClan(CurrentHedgehog)))
 
 end
 
@@ -678,6 +721,8 @@ function onAmmoStoreInit()
 
 	SetAmmo(amFirePunch, 9, 0, 0, 0)
 	SetAmmo(amBaseballBat, 2, 0, 0, 0)
+	--SetAmmo(amKamikaze, 2, 0, 0, 0)
+
 
 	SetAmmo(amDynamite,2,0,0,1)
 	SetAmmo(amSMine,4,0,0,0)
@@ -689,7 +734,7 @@ function onAmmoStoreInit()
 
 	SetAmmo(amParachute, 9, 0, 0, 0)
 	SetAmmo(amRope, 9, 0, 0, 0)
-	SetAmmo(amTeleport, 1, 0, 0, 1)
+	SetAmmo(amTeleport, 0, 0, 0, 1)
 	SetAmmo(amJetpack, 1, 0, 0, 1)
 
 	SetAmmo(amSwitch, 2, 0, 0, 1)
@@ -717,17 +762,17 @@ function onGearResurrect(gear)
 	elseif GetHogClan(gear) == 1 then
 		FindPlace(gear, false, 2048, LAND_WIDTH)
 	end
-	
+
 	AddVisualGear(GetX(gear), GetY(gear), vgtBigExplosion, 0, false)
 
 end
 
 function onGearDamage(gear, damage)
 
-	-- >_< damn, occurs too fast, before the hog has finished moving / updated his health	
+	-- >_< damn, occurs too fast, before the hog has finished moving / updated his health
 	--if GetGearType(gear) == gtHedgehog then
 	--	if damage > GetHealth(gear) then
-	--		AddVisualGear(GetX(gear), GetY(gear), vgtExplosion, 0, false)		
+	--		AddVisualGear(GetX(gear), GetY(gear), vgtExplosion, 0, false)
 	--	end
 	--end
 
@@ -743,6 +788,10 @@ function onGearAdd(gear)
 
 	end
 
+	if GetGearType(gear) == gtRope then
+		ropeGear = gear
+	end
+
 end
 
 function onGearDelete(gear)
@@ -751,4 +800,22 @@ function onGearDelete(gear)
 		FlagDeleted(gear)
 	end
 
+	if GetGearType(gear) == gtRope then
+		ropeGear = nil
+	end
+
+	if GetGearType(gear) == gtHedgehog then
+		for i = 0, (numhhs-1) do
+			if gear == hhs[i] then
+				
+				for k = 0,1 do
+					if gear == fThief[k] then
+						FlagThiefDead(gear)
+					end
+				end				
+				hhs[i] = nil	
+			end		
+		end
+	end
+
 end
